==> maplat-0.5.4.tgz: package/README.md <==
![Maplat Logo](https://code4history.github.io/Maplat/page_imgs/maplat.png)
![Maplat Catch Phrase](https://code4history.github.io/Maplat/page_imgs/bijective.png)

Maplat is the cool Historical Map/Illustrated Map Viewer.  
It can transform each map coordinates with nonlinear but bijective projection and makes possible that the maps can collaborate with GPS/accurate maps, without distorting original maps.  
Data editor of this solution is provided as another project, [MaplatEditor](https://github.com/code4nara/MaplatEditor/).  
This project won Grand Prize / Educational Effectiveness Prize / Visitors Selection Prize on Geo-Activity Contest 2018 held by Ministry of Land, Infrastructure, Transport and Tourism.

Maplatは古地図/絵地図を歪める事なくGPSや正確な地図と連携させられるオープンソースプラットフォームです。  
他のソリューションにない特徴として、各地図の座標変換において非線形かつ全単射な投影変換が定義可能という点が挙げられます。  
このプロジェクトは国土交通省主催の2018年ジオアクティビティコンテストにおいて、最優秀賞、教育効果賞、来場者賞をいただきました。

# Introduction slide (In English, ICC Tokyo 2019)
<a href="https://www.slideshare.net/kokogiko/maplat-historical-map-viewer-technology-that-guarantees-nonlinear-bijective-conversion-without-distortion">![Introduction of Maplat](https://code4history.github.io/Maplat/page_imgs/maplat_slide.png)</a>

# <a href="https://www.slideshare.net/kokogiko/maplat-historical-viewer-technology-that-guarantees-nonlinear-bijective-conversion-without-distortion">ICC Tokyo 2019 paper</a>

# Introduction slide (In Japanese, FOSS4G Tokyo 2017)
<a href="https://www.slideshare.net/kokogiko/maplat">![Introduction of Maplat](https://code4history.github.io/Maplat/page_imgs/maplat_slide.png)</a>

# Data Editor
Please use [MaplatEditor](https://github.com/code4nara/MaplatEditor/) for data creation.

データの作成には[MaplatEditor](https://github.com/code4nara/MaplatEditor/)を利用してください。

# Latest result
Latest result is shown below:
* https://s.maplat.jp/r/naramap/ (Maplat Nara)
* https://s.maplat.jp/r/aizumap/ (Maplat Aizuwakamatsu)
* https://s.maplat.jp/r/iwakimap/ (Maplat Iwaki)
* https://s.maplat.jp/r/tatebayashimap/ (Maplat Tatebayashi)
* https://s.maplat.jp/r/chuokumap/ (Maplat Tokyo Chuo-ku)
* https://s.maplat.jp/r/uedamap/ (Ueda city)
* https://s.maplat.jp/r/moriokamap/ (Morioka city)
* https://s.maplat.jp/r/sabaemap/ (Sabae city)
* https://s.maplat.jp/r/nobeokamap/ (Nobeoka city)

Documentation is undergoing.

最新の成果物は以下で確認できます。
* https://s.maplat.jp/r/naramap/ (ぷらっと奈良)
* https://s.maplat.jp/r/aizumap/ (ぷらっと会津若松)
* https://s.maplat.jp/r/iwakimap/ (ぷらっといわき)
* https://s.maplat.jp/r/tatebayashimap/ (ぷらっと館林)
* https://s.maplat.jp/r/chuokumap/ (ぷらっと東京中央区)
* https://s.maplat.jp/r/uedamap/ (上田市版)
* https://s.maplat.jp/r/moriokamap/ (盛岡市版)
* https://s.maplat.jp/r/sabaemap/ (鯖江市版)
* https://s.maplat.jp/r/nobeokamap/ (延岡市版)

成果物を他人がコンテンツ作れる形でまとめられていないですが、おいおい整理します。

# Collaboration demo with Jizo project
Code 4 NaraからUrban data challenge 2016に応募中のMaplatと[地蔵プロジェクト](https://github.com/code4nara/JizoProject/wiki)をコラボレーションさせたデモを作りました。
* https://s.maplat.jp/r/narajizomap/

## Contributors

This project exists thanks to all the people who contribute. <!--[[Contribute](CONTRIBUTING.md)].-->
<a href="https://github.com/code4nara/Maplat/graphs/contributors"><img src="https://opencollective.com/maplat/contributors.svg?width=890&button=false" /></a>


## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/maplat#backer)]

<a href="https://opencollective.com/maplat#backers" target="_blank"><img src="https://opencollective.com/maplat/backers.svg?width=890"></a>


## Sponsors
Maplat is supported by <a href="https://www.jetbrains.com/" target="_blank"><img src="https://code4history.github.io/Maplat/img/jetbrains-variant-4.png" width="150"></a> <a href="https://www.locazing.com/" target="_blank"><img src="https://code4history.github.io/Maplat/img/locazing.png" width="150"></a> <a href="https://www.browserstack.com/" target="_blank"><img src="https://code4history.github.io/Maplat/img/browserstack-logo-600x315.png" width="150"></a>

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/maplat#sponsor)]

==> maplat-0.6.1.tgz: package/README.md <==
![Maplat Logo](https://code4history.github.io/Maplat/page_imgs/maplat.png)
![Maplat Catch Phrase](https://code4history.github.io/Maplat/page_imgs/bijective.png)

Maplat is the cool Historical Map/Illustrated Map Viewer.  
It can transform each map coordinates with nonlinear but homeomorphic projection and makes possible that the maps can collaborate with GPS/accurate maps, without distorting original maps.  
Data editor of this solution is provided as another project, [MaplatEditor](https://github.com/code4history/MaplatEditor/).  
This project won Grand Prize / Educational Effectiveness Prize / Visitors Selection Prize on Geo-Activity Contest 2018 held by Ministry of Land, Infrastructure, Transport and Tourism.

Maplatは古地図/絵地図を歪める事なくGPSや正確な地図と連携させられるオープンソースプラットフォームです。  
他のソリューションにない特徴として、各地図の座標変換において非線形かつ同相な投影変換が定義可能という点が挙げられます。  
このプロジェクトは国土交通省主催の2018年ジオアクティビティコンテストにおいて、最優秀賞、教育効果賞、来場者賞をいただきました。

# Important Notice - deprecated

maplat module is renamed as @maplat/ui.  
Please use [@maplat/ui](https://www.npmjs.com/package/@maplat/ui) module instead.

# Introduction slide (In English, ICC Tokyo 2019)
<a href="https://www.slideshare.net/kokogiko/maplat-historical-map-viewer-technology-that-guarantees-nonlinear-bijective-conversion-without-distortion">![Introduction of Maplat](https://code4history.github.io/Maplat/page_imgs/maplat_slide.png)</a>

# <a href="https://www.slideshare.net/kokogiko/maplat-historical-viewer-technology-that-guarantees-nonlinear-bijective-conversion-without-distortion">ICC Tokyo 2019 paper</a>

# Introduction slide (In Japanese, FOSS4G Tokyo 2017)
<a href="https://www.slideshare.net/kokogiko/maplat">![Introduction of Maplat](https://code4history.github.io/Maplat/page_imgs/maplat_slide.png)</a>

# Data Editor
Please use [MaplatEditor](https://github.com/code4history/MaplatEditor/) for data creation.

データの作成には[MaplatEditor](https://github.com/code4history/MaplatEditor/)を利用してください。

# Latest result
Latest result is shown below:
* https://s.maplat.jp/r/naramap/ (Maplat Nara)
* https://s.maplat.jp/r/aizumap/ (Maplat Aizuwakamatsu)
* https://s.maplat.jp/r/iwakimap/ (Maplat Iwaki)
* https://s.maplat.jp/r/tatebayashimap/ (Maplat Tatebayashi)
* https://s.maplat.jp/r/chuokumap/ (Maplat Tokyo Chuo-ku)
* https://s.maplat.jp/r/uedamap/ (Ueda city)
* https://s.maplat.jp/r/moriokamap/ (Morioka city)
* https://s.maplat.jp/r/sabaemap/ (Sabae city)
* https://s.maplat.jp/r/nobeokamap/ (Nobeoka city)

Documentation is undergoing.

最新の成果物は以下で確認できます。
* https://s.maplat.jp/r/naramap/ (ぷらっと奈良)
* https://s.maplat.jp/r/aizumap/ (ぷらっと会津若松)
* https://s.maplat.jp/r/iwakimap/ (ぷらっといわき)
* https://s.maplat.jp/r/tatebayashimap/ (ぷらっと館林)
* https://s.maplat.jp/r/chuokumap/ (ぷらっと東京中央区)
* https://s.maplat.jp/r/uedamap/ (上田市版)
* https://s.maplat.jp/r/moriokamap/ (盛岡市版)
* https://s.maplat.jp/r/sabaemap/ (鯖江市版)
* https://s.maplat.jp/r/nobeokamap/ (延岡市版)

成果物を他人がコンテンツ作れる形でまとめられていないですが、おいおい整理します。

# Collaboration demo with Jizo project
Code 4 NaraからUrban data challenge 2016に応募中のMaplatと[地蔵プロジェクト](https://github.com/code4nara/JizoProject/wiki)をコラボレーションさせたデモを作りました。
* https://s.maplat.jp/r/narajizomap/

## Contributors

This project exists thanks to all the people who contribute. <!--[[Contribute](CONTRIBUTING.md)].-->
<a href="https://github.com/code4nara/Maplat/graphs/contributors"><img src="https://opencollective.com/maplat/contributors.svg?width=890&button=false" /></a>


## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/maplat#backer)]

<a href="https://opencollective.com/maplat#backers" target="_blank"><img src="https://opencollective.com/maplat/backers.svg?width=890"></a>


## Sponsors
Maplat is supported by <a href="https://www.jetbrains.com/" target="_blank"><img src="https://code4history.github.io/Maplat/img/jetbrains-variant-4.png" width="150"></a> <a href="https://www.locazing.com/" target="_blank"><img src="https://code4history.github.io/Maplat/img/locazing.png" width="150"></a> <a href="https://www.browserstack.com/" target="_blank"><img src="https://code4history.github.io/Maplat/img/browserstack-logo-600x315.png" width="150"></a>

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/maplat#sponsor)]
